@@ -1,3 +1,6 @@
+# Copyright 2021 UW-IT, University of Washington
+# SPDX-License-Identifier: Apache-2.0
+
 # This is just a test runner for coverage
 from commonconf.backends import use_configparser_backend
 from os.path import abspath, dirname
@@ -5,7 +8,7 @@ import os
 
 if __name__ == '__main__':
     path = abspath(os.path.join(dirname(__file__),
-                                "..", "travis-ci", "test.conf"))
+                                "..", "conf", "test.conf"))
     use_configparser_backend(path, 'Bookstore')
 
     from nose2 import discover
